ajdmom.poly
===========

.. automodule:: ajdmom.poly

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      kv
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Poly
   
   

   
   
   



